Introduction
============

The `ftw.publisher` packages provide tools for publishing plone contents from
one instance to another.

This package provides shared tools and utils used by `ftw.publisher.sender` and
`ftw.publisher.receiver`.

Links
=====

The main project package is `ftw.publisher.sender` since it contains all the
configuration panels and the most tools - but without the other mandatory
packages it will not work.
Here are some additional links:

- Publisher packages on pypi: http://pypi.python.org/pypi?%3Aaction=search&term=ftw.publisher&submit=search
- Main github project repository: https://github.com/4teamwork/ftw.publisher.sender
- Issue tracker: https://github.com/4teamwork/ftw.publisher.sender/issues
- Wiki: https://github.com/4teamwork/ftw.publisher.sender/wiki


Credits
=======

Sponsored by `4teamwork GmbH <http://www.4teamwork.ch/>`_.

Authors:

- `jone <http://github.com/jone>`_
- `maethu <https://github.com/maethu>`_
